@@ -157,10 +157,6 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
         progress.setLabelText("Loading graphical elements")
 
-        progress.setValue(35)
-
-        self.filter_field = SearchWidget(channels_db_items, self.mdf.channels_db, self)
-
         progress.setValue(37)
 
         splitter = QtWidgets.QSplitter(self)
@@ -175,23 +171,8 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
         self.channels_tree = TreeWidget(channel_and_search)
         self.channels_tree.setDragEnabled(True)
-        self.search_field = SearchWidget(
-            channels_db_items, self.mdf.channels_db, channel_and_search
-        )
-        self.filter_tree = TreeWidget()
 
-        self.search_field.selectionChanged.connect(
-            partial(
-                self.new_search_result,
-                tree=self.channels_tree,
-                search=self.search_field,
-            )
-        )
-        self.filter_field.selectionChanged.connect(
-            partial(
-                self.new_search_result, tree=self.filter_tree, search=self.filter_field
-            )
-        )
+        self.filter_tree = TreeWidget()
 
         vbox = QtWidgets.QVBoxLayout(channel_and_search)
         vbox.setSpacing(2)
@@ -201,7 +182,6 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
         self.advanced_search_btn.setIcon(icon)
         self.advanced_search_btn.setToolTip("Advanced search and select channels")
         self.advanced_search_btn.clicked.connect(self.search)
-        vbox.addWidget(self.search_field)
         vbox.addWidget(self.channel_view)
 
         vbox.addWidget(self.channels_tree, 1)
@@ -271,8 +251,6 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
         self.mdi_area.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
         self.splitter.addWidget(self.mdi_area)
 
-        self.filter_layout.addWidget(self.filter_field, 0, 0, 1, 1)
-
         self.channels_tree.itemDoubleClicked.connect(self.show_info)
         self.filter_tree.itemDoubleClicked.connect(self.show_info)
 
@@ -462,6 +440,7 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
         item = QtWidgets.QTreeWidgetItem()
         item.setText(0, 'Measurement comment')
         item.setText(1, self.mdf.header.comment)
+        item.setTextAlignment(0, QtCore.Qt.AlignTop)
         children.append(item)
 
         channel_groups = QtWidgets.QTreeWidgetItem()
@@ -521,6 +500,8 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
         self.info.expandAll()
 
+        self.info.header().setSectionResizeMode(0, QtWidgets.QHeaderView.ResizeToContents)
+
         # self.channels_tree.itemChanged.connect(self.select)
         self.create_window_btn.clicked.connect(self._create_window)
 
@@ -555,48 +536,37 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
     def _update_channel_tree(self, index=None):
         if self.channel_view.currentIndex() == -1:
             return
-        iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
-        signals = set()
+        for widget in (self.channels_tree, self.filter_tree):
+            iterator = QtWidgets.QTreeWidgetItemIterator(widget)
+            signals = set()
+
+            if self.channel_view.currentIndex() == 0:
+                while iterator.value():
+                    item = iterator.value()
+                    if item.parent() is None:
+                        iterator += 1
+                        continue
+
+                    if item.checkState(0) == QtCore.Qt.Checked:
+                        signals.add(item.entry)
 
-        if self.channel_view.currentIndex() == 0:
-            while iterator.value():
-                item = iterator.value()
-                if item.parent() is None:
                     iterator += 1
-                    continue
+            else:
+                while iterator.value():
+                    item = iterator.value()
 
-                if item.checkState(0) == QtCore.Qt.Checked:
-                    signals.add(item.entry)
+                    if item.checkState(0) == QtCore.Qt.Checked:
+                        signals.add(item.entry)
 
-                iterator += 1
-        else:
-            while iterator.value():
-                item = iterator.value()
+                    iterator += 1
 
-                if item.checkState(0) == QtCore.Qt.Checked:
-                    signals.add(item.entry)
+            widget.clear()
 
-                iterator += 1
-
-        self.channels_tree.clear()
-
-        if self.channel_view.currentIndex() == 0:
-            items = []
-            for i, group in enumerate(self.mdf.groups):
-                for j, ch in enumerate(group.channels):
-                    entry = i, j
-
-                    channel = TreeItem(entry, ch.name)
-                    channel.setText(0, ch.name)
-                    if entry in signals:
-                        channel.setCheckState(0, QtCore.Qt.Checked)
-                    else:
-                        channel.setCheckState(0, QtCore.Qt.Unchecked)
-                    items.append(channel)
-
-                if self.mdf.version >= "4.00":
-                    for j, ch in enumerate(group.logging_channels, 1):
-                        entry = i, -j
+            if self.channel_view.currentIndex() == 0:
+                items = []
+                for i, group in enumerate(self.mdf.groups):
+                    for j, ch in enumerate(group.channels):
+                        entry = i, j
 
                         channel = TreeItem(entry, ch.name)
                         channel.setText(0, ch.name)
@@ -605,57 +575,69 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                         else:
                             channel.setCheckState(0, QtCore.Qt.Unchecked)
                         items.append(channel)
-            if len(items) < 30000:
-                items = natsorted(items, key=lambda x: x.name)
-            else:
-                items.sort(key=lambda x: x.name)
-            self.channels_tree.addTopLevelItems(items)
-        else:
-            for i, group in enumerate(self.mdf.groups):
-                entry = i, 0xFFFFFFFFFFFFFFFF
-                channel_group = TreeItem(entry)
-                comment = group.channel_group.comment
-                comment = extract_cncomment_xml(comment)
 
-                if comment:
-                    channel_group.setText(0, f"Channel group {i} ({comment})")
+                    if self.mdf.version >= "4.00":
+                        for j, ch in enumerate(group.logging_channels, 1):
+                            entry = i, -j
+
+                            channel = TreeItem(entry, ch.name)
+                            channel.setText(0, ch.name)
+                            if entry in signals:
+                                channel.setCheckState(0, QtCore.Qt.Checked)
+                            else:
+                                channel.setCheckState(0, QtCore.Qt.Unchecked)
+                            items.append(channel)
+                if len(items) < 30000:
+                    items = natsorted(items, key=lambda x: x.name)
                 else:
-                    channel_group.setText(0, f"Channel group {i}")
-                channel_group.setFlags(
-                    channel_group.flags() | QtCore.Qt.ItemIsTristate | QtCore.Qt.ItemIsUserCheckable
-                )
+                    items.sort(key=lambda x: x.name)
+                widget.addTopLevelItems(items)
+            else:
+                for i, group in enumerate(self.mdf.groups):
+                    entry = i, 0xFFFFFFFFFFFFFFFF
+                    channel_group = TreeItem(entry)
+                    comment = group.channel_group.comment
+                    comment = extract_cncomment_xml(comment)
 
-                self.channels_tree.addTopLevelItem(channel_group)
-
-                group_children = []
-
-                for j, ch in enumerate(group.channels):
-                    entry = i, j
-
-                    channel = TreeItem(entry, ch.name)
-                    channel.setText(0, ch.name)
-                    if entry in signals:
-                        channel.setCheckState(0, QtCore.Qt.Checked)
+                    if comment:
+                        channel_group.setText(0, f"Channel group {i} ({comment})")
                     else:
-                        channel.setCheckState(0, QtCore.Qt.Unchecked)
-                    group_children.append(channel)
+                        channel_group.setText(0, f"Channel group {i}")
+                    channel_group.setFlags(
+                        channel_group.flags() | QtCore.Qt.ItemIsTristate | QtCore.Qt.ItemIsUserCheckable
+                    )
 
-                if self.mdf.version >= "4.00":
-                    for j, ch in enumerate(group.logging_channels, 1):
-                        name = ch.name
-                        entry = i, -j
+                    widget.addTopLevelItem(channel_group)
 
-                        channel = TreeItem(entry, name)
-                        channel.setText(0, name)
+                    group_children = []
+
+                    for j, ch in enumerate(group.channels):
+                        entry = i, j
+
+                        channel = TreeItem(entry, ch.name)
+                        channel.setText(0, ch.name)
                         if entry in signals:
                             channel.setCheckState(0, QtCore.Qt.Checked)
                         else:
                             channel.setCheckState(0, QtCore.Qt.Unchecked)
                         group_children.append(channel)
 
-                channel_group.addChildren(group_children)
+                    if self.mdf.version >= "4.00":
+                        for j, ch in enumerate(group.logging_channels, 1):
+                            name = ch.name
+                            entry = i, -j
 
-                del group_children
+                            channel = TreeItem(entry, name)
+                            channel.setText(0, name)
+                            if entry in signals:
+                                channel.setCheckState(0, QtCore.Qt.Checked)
+                            else:
+                                channel.setCheckState(0, QtCore.Qt.Unchecked)
+                            group_children.append(channel)
+
+                    channel_group.addChildren(group_children)
+
+                    del group_children
 
         self._settings.setValue('channels_view', self.channel_view.currentText())
 
@@ -688,6 +670,9 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
             if current_plot:
                 current_plot.plot.update_lines(with_dots=with_dots)
 
+    def set_subplots(self, option):
+        self.subplots = option
+
     def set_subplots_link(self, subplots_link):
         self.subplots_link = subplots_link
         viewbox = None
@@ -761,9 +746,15 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 mdf.save(file_name, overwrite=True)
 
     def search(self):
+        if self.aspects.tabText(self.aspects.currentIndex()) == 'Channels':
+            show_add_window = True
+            widget = self.channels_tree
+        else:
+            show_add_window = False
+            widget = self.filter_tree
         dlg = AdvancedSearch(
             self.mdf.channels_db,
-            show_add_window=True,
+            show_add_window=show_add_window,
             parent=self,
         )
         dlg.setModal(True)
@@ -772,7 +763,7 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
         if result:
             names = set()
             if self.channel_view.currentIndex() == 1:
-                iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
+                iterator = QtWidgets.QTreeWidgetItemIterator(widget)
 
                 dg_cntr = -1
                 ch_cntr = 0
@@ -792,7 +783,7 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                     iterator += 1
                     ch_cntr += 1
             else:
-                iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
+                iterator = QtWidgets.QTreeWidgetItemIterator(widget)
                 while iterator.value():
                     item = iterator.value()
 
@@ -831,6 +822,53 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                         widget = widgets[index-3]
                         self.add_new_channels(names, widget)
 
+    def to_config(self):
+        config = {}
+
+        iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
+
+        signals = []
+        if self.channel_view.currentIndex() == 1:
+            while iterator.value():
+                item = iterator.value()
+                if item.parent() is None:
+                    iterator += 1
+                    continue
+
+                if item.checkState(0) == QtCore.Qt.Checked:
+                    signals.append(item.text(0))
+
+                iterator += 1
+        else:
+            while iterator.value():
+                item = iterator.value()
+
+                if item.checkState(0) == QtCore.Qt.Checked:
+                    signals.append(item.text(0))
+
+                iterator += 1
+
+        config['selected_channels'] = signals
+
+        windows = []
+        for window in self.mdi_area.subWindowList():
+            wid = window.widget()
+            window_config = {
+                'title': window.windowTitle(),
+                'configuration': wid.to_config(),
+            }
+            if isinstance(wid, Numeric):
+                window_config['type'] = 'Numeric'
+            elif isinstance(wid, Plot):
+                window_config['type'] = 'Plot'
+            else:
+                window_config['type'] = 'Tabular'
+            windows.append(window_config)
+
+        config['windows'] = windows
+
+        return config
+
     def save_channel_list(self, event=None, file_name=None):
 
         if file_name is None:
@@ -839,52 +877,9 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
             )
 
         if file_name:
-
-            config = {}
-            with open(file_name, "w") as output:
-                iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
-
-                signals = []
-                if self.channel_view.currentIndex() == 1:
-                    while iterator.value():
-                        item = iterator.value()
-                        if item.parent() is None:
-                            iterator += 1
-                            continue
-
-                        if item.checkState(0) == QtCore.Qt.Checked:
-                            signals.append(item.text(0))
-
-                        iterator += 1
-                else:
-                    while iterator.value():
-                        item = iterator.value()
-
-                        if item.checkState(0) == QtCore.Qt.Checked:
-                            signals.append(item.text(0))
-
-                        iterator += 1
-
-                config['selected_channels'] = signals
-
-                windows = []
-                for window in self.mdi_area.subWindowList():
-                    wid = window.widget()
-                    window_config = {
-                        'title': window.windowTitle(),
-                        'configuration': wid.to_config(),
-                    }
-                    if isinstance(wid, Numeric):
-                        window_config['type'] = 'Numeric'
-                    elif isinstance(wid, Plot):
-                        window_config['type'] = 'Plot'
-                    else:
-                        window_config['type'] = 'Tabular'
-                    windows.append(window_config)
-
-                config['windows'] = windows
-
-                output.write(json.dumps(config, indent=4, sort_keys=True))
+            Path(file_name).write_text(
+                json.dumps(self.to_config(), indent=4, sort_keys=True)
+            )
 
     def load_channel_list(self, event=None, file_name=None):
         if file_name is None:
@@ -893,42 +888,47 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
             )
 
         if file_name:
-            with open(file_name, "r") as infile:
-                info = json.load(infile)
-
-            channels = info['selected_channels']
-
-            iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
-
-            if self.channel_view.currentIndex() == 1:
-                while iterator.value():
-                    item = iterator.value()
-                    if item.parent() is None:
-                        iterator += 1
-                        continue
-
-                    channel_name = item.text(0)
-                    if channel_name in channels:
-                        item.setCheckState(0, QtCore.Qt.Checked)
-                        channels.pop(channels.index(channel_name))
-                    else:
-                        item.setCheckState(0, QtCore.Qt.Unchecked)
-
-                    iterator += 1
+            if not isinstance(file_name, dict):
+                with open(file_name, "r") as infile:
+                    info = json.load(infile)
             else:
-                while iterator.value():
-                    item = iterator.value()
+                info = file_name
 
-                    channel_name = item.text(0)
-                    if channel_name in channels:
-                        item.setCheckState(0, QtCore.Qt.Checked)
-                        channels.pop(channels.index(channel_name))
-                    else:
-                        item.setCheckState(0, QtCore.Qt.Unchecked)
+            channels = info.get('selected_channels', [])
 
-                    iterator += 1
+            if channels:
 
-            for window in info['windows']:
+                iterator = QtWidgets.QTreeWidgetItemIterator(self.channels_tree)
+
+                if self.channel_view.currentIndex() == 1:
+                    while iterator.value():
+                        item = iterator.value()
+                        if item.parent() is None:
+                            iterator += 1
+                            continue
+
+                        channel_name = item.text(0)
+                        if channel_name in channels:
+                            item.setCheckState(0, QtCore.Qt.Checked)
+                            channels.pop(channels.index(channel_name))
+                        else:
+                            item.setCheckState(0, QtCore.Qt.Unchecked)
+
+                        iterator += 1
+                else:
+                    while iterator.value():
+                        item = iterator.value()
+
+                        channel_name = item.text(0)
+                        if channel_name in channels:
+                            item.setCheckState(0, QtCore.Qt.Checked)
+                            channels.pop(channels.index(channel_name))
+                        else:
+                            item.setCheckState(0, QtCore.Qt.Unchecked)
+
+                        iterator += 1
+
+            for window in info.get('windows', []):
                 self.load_window(window)
 
     def save_filter_list(self):
@@ -1092,36 +1092,10 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
         else:
             return None
 
-    def new_search_result(self, tree, search):
-        group_index, channel_index = search.entries[search.current_index]
-
-        iterator = QtWidgets.QTreeWidgetItemIterator(tree)
-
-        if self.channel_view.currentIndex() == 1:
-
-            while iterator.value():
-                item = iterator.value()
-                if item.parent() is not None:
-                    if item.entry == (group_index, channel_index):
-
-                        tree.scrollToItem(item, QtWidgets.QAbstractItemView.PositionAtTop)
-                        item.setSelected(True)
-                        tree.setFocus()
-                iterator += 1
-        else:
-            while iterator.value():
-                item = iterator.value()
-                if item.entry == (group_index, channel_index):
-
-                    tree.scrollToItem(item, QtWidgets.QAbstractItemView.PositionAtTop)
-                    item.setSelected(True)
-                    tree.setFocus()
-                iterator += 1
-
     def close(self):
         mdf_name = self.mdf.name
         self.mdf.close()
-        if self.file_name.suffix.lower() == ".dl3":
+        if self.file_name.suffix.lower() in (".dl3", ".erg"):
             mdf_name.unlink()
 
     def convert(self, event):
@@ -1393,6 +1367,12 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 icon_name="export",
             )
 
+            if export_type == 'mat':
+                if compression:
+                    compression = True if compression == 'enabled' else False
+                else:
+                    compression = False
+
             # cut self.mdf
             target = self.mdf.export
             kwargs={
@@ -1447,6 +1427,10 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 ignore_value2text_conversions=self.ignore_value2text_conversions,
                 time_from_zero=False,
             )
+
+            for name in signals.columns:
+                if name.endswith('CAN_DataFrame.ID'):
+                    signals[name] = signals[name].astype('<u4') & 0x1fffffff
         else:
 
             signals = self.mdf.select(
@@ -1468,6 +1452,9 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 if len(signal.samples.shape) > 1:
                     signal.samples = csv_bytearray2hex(pd.Series(list(signal.samples))).astype(bytes)
 
+                if signal.name.endswith('CAN_DataFrame.ID'):
+                    signal.samples = signal.samples.astype('<u4') & 0x1fffffff
+
             signals = natsorted(signals, key=lambda x: x.name)
 
         if window_type == 'Numeric':
@@ -1619,6 +1606,10 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 for name in window_info['configuration']['channels']
                 if name in self.mdf
             ]
+
+            if not signals_:
+                return
+
             signals = self.mdf.select(
                 signals_,
                 ignore_value2text_conversions=self.ignore_value2text_conversions,
@@ -1886,6 +1877,9 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
             signals = list(measured_signals.values()) + list(computed_signals.values())
 
+            if not signals:
+                return
+
             plot = Plot([], self.with_dots)
 
             if not self.subplots:
@@ -1975,6 +1969,10 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 for name in window_info['configuration']['channels']
                 if name in self.mdf
             ]
+
+            if not signals_:
+                return
+
             signals = self.mdf.to_dataframe(
                 channels=signals_,
                 ignore_value2text_conversions=self.ignore_value2text_conversions,
@@ -2325,9 +2323,11 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
             call_info = dict(self.mdf.last_call_info)
 
+            found_id_count = sum(len(e) for e in call_info["found_ids"].values())
+
             message = [
                 'Summary:',
-                f'- {sum(len(s) for s in call_info["found_ids"])} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
+                f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
             ]
             if call_info['unknown_id_count']:
                 message.append(f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file')
@@ -2436,9 +2436,11 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
             call_info = dict(self.mdf.last_call_info)
 
+            found_id_count = sum(len(e) for e in call_info["found_ids"].values())
+
             message = [
                 'Summary:',
-                f'- {call_info["found_id_count"]} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
+                f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
             ]
             if call_info['unknown_id_count']:
                 message.append(f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file')
@@ -2475,3 +2477,13 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
 
         if file_names:
             self.can_database_list.addItems(file_names)
+
+    def keyPressEvent(self, event):
+        key = event.key()
+        modifier = event.modifiers()
+
+        if key == QtCore.Qt.Key_F and modifier == QtCore.Qt.ControlModifier:
+            self.search()
+        else:
+            super().keyPressEvent(event)
+
