@@ -73,23 +73,6 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         menu = QtWidgets.QMenu("Settings", self.menubar)
         self.menubar.addMenu(menu)
 
-        # search mode menu
-        search_option = QtWidgets.QActionGroup(self)
-
-        for option in ("Match start", "Match contains"):
-
-            action = QtWidgets.QAction(option, menu)
-            action.setCheckable(True)
-            search_option.addAction(action)
-            action.triggered.connect(partial(self.set_search_option, option))
-
-            if option == self._settings.value('search_match', "Match start"):
-                action.setChecked(True)
-
-        submenu = QtWidgets.QMenu("Search", self.menubar)
-        submenu.addActions(search_option.actions())
-        menu.addMenu(submenu)
-
         # sub plots
         subplot_action = QtWidgets.QAction('Sub-plots', menu)
         subplot_action.setCheckable(True)
@@ -345,7 +328,6 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
         self.show()
 
-        self.set_search_option(self._settings.value('search_match', "Match start"))
         self.set_subplot_option(self._settings.value('subplots', "Disabled"))
         self.set_subplot_link_option(self._settings.value('subplots_link', "Disabled"))
 
@@ -384,20 +366,17 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             elif mode == 'tile horizontally':
                 widget.mdi_area.tile_horizontally()
 
-    def set_search_option(self, option):
-        self.match = option
-        self._settings.setValue('search_match', self.match)
-        count = self.files.count()
-        for i in range(count):
-            self.files.widget(i).search_field.set_search_option(option)
-            self.files.widget(i).filter_field.set_search_option(option)
-
     def set_subplot_option(self, state):
         if isinstance(state, str):
             state = True if state == 'true' else False
         self.subplots = state
         self._settings.setValue('subplots', state)
 
+        count = self.files.count()
+
+        for i in range(count):
+            self.files.widget(i).set_subplots(state)
+
     def set_plot_background(self, option):
         self._settings.setValue('plot_background', option)
         if option == 'Black':
@@ -617,8 +596,6 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                 self.ignore_value2text_conversions,
                 self,
             )
-            widget.search_field.set_search_option(self.match)
-            widget.filter_field.set_search_option(self.match)
         except:
             raise
         else:
@@ -713,3 +690,13 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         else:
             self.plot_menu.setEnabled(False)
             self.setWindowTitle(f'asammdf {libversion} - Batch processing')
+
+    def keyPressEvent(self, event):
+        key = event.key()
+        modifier = event.modifiers()
+
+        if key == QtCore.Qt.Key_F and modifier == QtCore.Qt.ControlModifier:
+            if self.files.count() and self.stackedWidget.currentIndex() == 0:
+                self.files.currentWidget().keyPressEvent(event)
+        else:
+            super().keyPressEvent(event)
